import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 *  A delivery source is an AWS resource that sends logs to an AWS destination. The destination can be CloudWatch Logs, Amazon S3, or Kinesis Data Firehose.
 *
 * Only some AWS services support being configured as a delivery source. These services are listed as Supported [V2 Permissions] in the table at [Enabling logging from AWS services](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/AWS-logs-and-resource-policy.html).
 */
export declare class DeliverySource extends pulumi.CustomResource {
    /**
     * Get an existing DeliverySource resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DeliverySource;
    /**
     * Returns true if the given object is an instance of DeliverySource.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DeliverySource;
    /**
     * The Amazon Resource Name (ARN) that uniquely identifies this delivery source.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The type of logs being delivered. Only mandatory when the resourceArn could match more than one. In such a case, the error message will contain all the possible options.
     */
    readonly logType: pulumi.Output<string | undefined>;
    /**
     * The unique name of the Log source.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ARN of the resource that will be sending the logs.
     */
    readonly resourceArn: pulumi.Output<string | undefined>;
    /**
     * This array contains the ARN of the AWS resource that sends logs and is represented by this delivery source. Currently, only one ARN can be in the array.
     */
    readonly resourceArns: pulumi.Output<string[]>;
    /**
     * The AWS service that is sending logs.
     */
    readonly service: pulumi.Output<string>;
    /**
     * The tags that have been assigned to this delivery source.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DeliverySource resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DeliverySourceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DeliverySource resource.
 */
export interface DeliverySourceArgs {
    /**
     * The type of logs being delivered. Only mandatory when the resourceArn could match more than one. In such a case, the error message will contain all the possible options.
     */
    logType?: pulumi.Input<string>;
    /**
     * The unique name of the Log source.
     */
    name?: pulumi.Input<string>;
    /**
     * The ARN of the resource that will be sending the logs.
     */
    resourceArn?: pulumi.Input<string>;
    /**
     * The tags that have been assigned to this delivery source.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
